package onvif

import (
	"fmt"
	"github.com/IOTechSystems/onvif/event"
	"github.com/IOTechSystems/onvif/gosoap"
	"github.com/gin-gonic/gin"
	"log"
	"net/http"
	"onvif-agent/config"
)

func CreateEventSubscription(c *gin.Context) {
	xaddr := c.Param("xaddr")
	callbackURL := event.AttributedURIType(fmt.Sprintf("%s/subscriptions/callback", config.Conf.App.URL))
	result, err := conns[xaddr].SubscribeEvents(callbackURL, "PT60S")
	if err != nil {
		c.JSON(http.StatusServiceUnavailable, gin.H{
			"message": err.Error(),
		})
		return
	}

	c.JSON(http.StatusOK, result)
}

func EventNotifyCallback(c *gin.Context) {
	var notify event.Notify
	envelope := gosoap.NewSOAPEnvelope(&notify)
	if err := c.ShouldBindXML(&envelope); err != nil {
		c.JSON(http.StatusBadRequest, gin.H{"error": err.Error()})
		return
	}

	// TODO: handle notifications
	for _, msg := range envelope.Body.Content.(*event.Notify).NotificationMessage {
		log.Println(msg.Topic.TopicKinds, msg.Message.Message)
	}

	c.JSON(http.StatusOK, gin.H{"message": "OK"})
}
